@@ -14,7 +14,7 @@ use Tk::Wizard::Installer;
 use base 'Tk::Wizard::Installer';
 my @EXPORT = ("MainLoop");
 
-our $VERSION = do { my @r = ( q$Revision: 2.15 $ =~ /\d+/g ); sprintf "%d." . "%03d" x $#r, @r };
+our $VERSION = do { my @r = ( q$Revision: 2.16 $ =~ /\d+/g ); sprintf "%d." . "%03d" x $#r, @r };
 
 use constant DEBUG_FRAME => 0;
 
@@ -22,7 +22,7 @@ BEGIN {
 	eval { require Log::Log4perl; };
 	if($@) {
 		no strict qw(refs);
-		*{"main::$_"} = sub { } for qw(TRACE DEBUG INFO WARN ERROR FATAL);
+		*{__PACKAGE__."::$_"} = sub { } for qw(TRACE DEBUG INFO WARN ERROR FATAL);
 	} else {
 		no warnings;
 		require Log::Log4perl::Level;
